@@ -21,20 +21,23 @@
 
 # Python module imports.
 from math import pi
-from os import F_OK, access, getcwd, listdir, sep
+from os import F_OK, R_OK, W_OK, X_OK, access, getcwd, listdir, sep
+from os.path import isdir
 from re import search
+import sys
 from time import sleep
 
 # relax module imports.
-from lib.float import floatAsByteArray
 from info import Info_box; info = Info_box()
+from lib.errors import RelaxError, RelaxNoSequenceError, RelaxNoValueError
+from lib.float import floatAsByteArray
+from lib.text.sectioning import title, subtitle
+from lib.text.string import LIST, PARAGRAPH, SECTION, SUBSECTION, TITLE, to_docstring
 from pipe_control.interatomic import interatomic_loop
 from pipe_control.mol_res_spin import exists_mol_res_spin_data, return_spin, spin_loop
 from pipe_control.pipes import cdp_name, get_pipe, has_pipe, pipe_names, switch
-from pipe_control import spectrometer
+from pipe_control.spectrometer import get_frequencies
 from prompt.interpreter import Interpreter
-from lib.errors import RelaxError, RelaxNoSequenceError, RelaxNoValueError
-from lib.text.string import LIST, PARAGRAPH, SECTION, SUBSECTION, TITLE, to_docstring
 from status import Status; status = Status()
 
 
@@ -152,6 +155,9 @@ class dAuvergne_protocol:
         @type conv_loop:                bool
         """
 
+        # Printout.
+        title(file=sys.stdout, text="The dauvergne_protocol model-free auto-analysis")
+
         # Execution lock.
         status.exec_lock.acquire(pipe_bundle, mode='auto-analysis')
 
@@ -250,6 +256,9 @@ class dAuvergne_protocol:
     def check_vars(self):
         """Check that the user has set the variables correctly."""
 
+        # Printout.
+        subtitle(file=sys.stdout, text="Auto-analysis variable checking")
+
         # The pipe bundle.
         if not isinstance(self.pipe_bundle, str):
             raise RelaxError("The pipe bundle name '%s' is invalid." % self.pipe_bundle)
@@ -341,11 +350,8 @@ class dAuvergne_protocol:
     def convergence(self):
         """Test for the convergence of the global model."""
 
-        # Print out.
-        print("\n\n\n")
-        print("#####################")
-        print("# Convergence tests #")
-        print("#####################\n")
+        # Printout.
+        title(file=sys.stdout, text="Convergence testing")
 
         # Maximum number of iterations reached.
         if self.max_iter and self.round > self.max_iter:
@@ -494,14 +500,36 @@ class dAuvergne_protocol:
     def determine_rnd(self, model=None):
         """Function for returning the name of next round of optimisation."""
 
-        # Get a list of all files in the directory model.  If no directory exists, set the round to 'init' or 0.
-        try:
-            dir_list = listdir(self.results_dir+sep+model)
-        except:
+        # The base model directory.
+        base_dir = self.results_dir+sep+model
+
+        # Printout.
+        subtitle(file=sys.stdout, text="Determining the next round of optimisation")
+        print("%-30s %s" % ("Base model directory:", base_dir))
+
+        # Catch if a file exists with the name of the directory.
+        if not isdir(base_dir) and access(base_dir, F_OK):
+            raise RelaxError("The base model directory '%s' is not usable as a file with the same name already exists." % base_dir)
+
+        # If no directory exists, set the round to 'init' or 0.
+        if not isdir(base_dir):
+            print("%-30s %i" % ("Round:", 0))
+            print("The base directory does not exist.")
             return 0
 
+        # Is the directory readable, writable, and executable.
+        if not access(base_dir, R_OK):
+            raise RelaxError("The base model directory '%s' is not readable." % base_dir)
+        if not access(base_dir, X_OK):
+            raise RelaxError("The base model directory '%s' is not executable." % base_dir)
+
+        # Get a list of all files in the directory model.
+        dir_list = listdir(base_dir)
+
         # Set the round to 'init' or 0 if there is no directory called 'init'.
         if 'init' not in dir_list:
+            print("%-30s %i" % ("Round:", 0))
+            print("No 'init' directory present in the base directory.")
             return 0
 
         # Create a list of all files which begin with 'round_'.
@@ -521,6 +549,8 @@ class dAuvergne_protocol:
 
         # No directories beginning with 'round_' exist, set the round to 1.
         if not len(numbers):
+            print("%-30s %i" % ("Round:", 1))
+            print("No directories beginning with 'round_' exist.")
             return 1
 
         # The highest number.
@@ -532,7 +562,7 @@ class dAuvergne_protocol:
             complete_round = i
 
             # The file root.
-            file_root = self.results_dir + sep + model + sep + "round_%i" % i + sep + 'opt' + sep + 'results'
+            file_root = base_dir + sep + "round_%i" % i + sep + 'opt' + sep + 'results'
 
             # Stop looping when the opt/results file is found.
             if access(file_root + '.bz2', F_OK):
@@ -544,9 +574,12 @@ class dAuvergne_protocol:
 
         # No round, so assume the initial state.
         if complete_round == 0:
+            print("%-30s %i" % ("Round:", 0))
+            print("No opt/results files can be found.")
             return 0
 
         # Determine the number for the next round (add 1 to the highest completed round).
+        print("%-30s %i" % ("Round:", complete_round + 1))
         return complete_round + 1
 
 
@@ -557,6 +590,9 @@ class dAuvergne_protocol:
         ################
 
         if self.diff_model == 'local_tm':
+            # Printout.
+            title(file=sys.stdout, text="Model MI - Local tm")
+
             # Base directory to place files into.
             self.base_dir = self.results_dir+'local_tm'+sep
 
@@ -571,6 +607,16 @@ class dAuvergne_protocol:
         #############################
 
         elif self.diff_model == 'sphere' or self.diff_model == 'prolate' or self.diff_model == 'oblate' or self.diff_model == 'ellipsoid':
+            # Printout.
+            if self.diff_model == 'sphere':
+                title(file=sys.stdout, text="Model MII - Spherical diffusion")
+            elif self.diff_model == 'prolate':
+                title(file=sys.stdout, text="Model MIII - Prolate spheroidal diffusion")
+            elif self.diff_model == 'oblate':
+                title(file=sys.stdout, text="Model MIV - Oblate spheroidal diffusion")
+            elif self.diff_model == 'ellipsoid':
+                title(file=sys.stdout, text="Model MV - Ellipsoidal diffusion")
+
             # No local_tm directory!
             dir_list = listdir(self.results_dir)
             if 'local_tm' not in dir_list:
@@ -588,6 +634,9 @@ class dAuvergne_protocol:
 
                 # Inital round of optimisation for diffusion models MII to MV.
                 if self.round == 0:
+                    # Printout.
+                    subtitle(file=sys.stdout, text="Initial round of optimisation")
+
                     # Base directory to place files into.
                     self.base_dir = self.results_dir+self.diff_model+sep+'init'+sep
 
@@ -630,6 +679,9 @@ class dAuvergne_protocol:
 
                 # Normal round of optimisation for diffusion models MII to MV.
                 else:
+                    # Printout.
+                    subtitle(file=sys.stdout, text="Round %i of optimisation" % self.round)
+
                     # Base directory to place files into.
                     self.base_dir = self.results_dir+self.diff_model + sep+'round_'+repr(self.round)+sep
 
@@ -667,9 +719,15 @@ class dAuvergne_protocol:
         ############
 
         elif self.diff_model == 'final':
+            # Printout.
+            title(file=sys.stdout, text="Final run")
+
             # Diffusion model selection.
             ############################
 
+            # Printout.
+            subtitle(file=sys.stdout, text="Diffusion model selection")
+
             # The contents of the results directory.
             dir_list = listdir(self.results_dir)
 
@@ -731,6 +789,9 @@ class dAuvergne_protocol:
             # Monte Carlo simulations.
             ##########################
 
+            # Printout.
+            subtitle(file=sys.stdout, text="Monte Carlo simulations")
+
             # Fix the diffusion tensor, if it exists.
             if hasattr(get_pipe(self.name_pipe('final')), 'diff_tensor'):
                 self.interpreter.fix('diff')
@@ -747,6 +808,9 @@ class dAuvergne_protocol:
             # Write the final results.
             ##########################
 
+            # Printout.
+            subtitle(file=sys.stdout, text="Writing the final results")
+
             # Create results files and plots of the data.
             self.write_results()
 
@@ -908,7 +972,7 @@ class dAuvergne_protocol:
         self.interpreter.value.write(param='ts',       file='ts.txt',       dir=dir, force=True)
         self.interpreter.value.write(param='rex',      file='rex.txt',      dir=dir, force=True)
         self.interpreter.value.write(param='local_tm', file='local_tm.txt', dir=dir, force=True)
-        frqs = spectrometer.get_frequencies()
+        frqs = get_frequencies()
         for i in range(len(frqs)):
             comment = "This is the Rex value with units rad.s^-1 scaled to a magnetic field strength of %s MHz." % (frqs[i]/1e6)
             self.interpreter.value.write(param='rex', file='rex_%s.txt'%int(frqs[i]/1e6), dir=dir, scaling=(2.0*pi*frqs[i])**2, comment=comment, force=True)
