@@ -1,7 +1,7 @@
 ###############################################################################
 #                                                                             #
 # Copyright (C) 2009 Michael Bieri                                            #
-# Copyright (C) 2010-2014 Edward d'Auvergne                                   #
+# Copyright (C) 2010-2015 Edward d'Auvergne                                   #
 #                                                                             #
 # This file is part of the program relax (http://www.nmr-relax.com).          #
 #                                                                             #
@@ -42,6 +42,18 @@ from pipe_control.pipes import cdp_name
 from status import Status; status = Status()
 
 
+# IDs for the menu entries.
+MENU_ID_FIND = wx.NewId()
+MENU_ID_COPY = wx.NewId()
+MENU_ID_SELECT_ALL = wx.NewId()
+MENU_ID_ZOOM_IN = wx.NewId()
+MENU_ID_ZOOM_OUT = wx.NewId()
+MENU_ID_ZOOM_ORIG = wx.NewId()
+MENU_ID_GOTO_START = wx.NewId()
+MENU_ID_GOTO_END = wx.NewId()
+
+
+
 class Controller(wx.Frame):
     """The relax controller window."""
 
@@ -125,6 +137,9 @@ class Controller(wx.Frame):
             info = Info_box()
             print(info.intro_text())
 
+        # Set the focus on the log control.
+        self.log_panel.SetFocus()
+
         # Register functions with the observer objects.
         status.observers.pipe_alteration.register('controller', self.update_controller, method_name='update_controller')
         status.observers.auto_analyses.register('controller', self.update_controller, method_name='update_controller')
@@ -234,6 +249,9 @@ class Controller(wx.Frame):
             text.SetToolTipString(tooltip)
             field.SetToolTipString(tooltip)
 
+        # Handle key events.
+        field.Bind(wx.EVT_KEY_DOWN, self.handler_key_down)
+
         # Return the control.
         return field
 
@@ -314,6 +332,18 @@ class Controller(wx.Frame):
         self.Hide()
 
 
+    def handler_key_down(self, event=None):
+        """Event handler for key strokes.
+
+        @keyword event: The wx event.
+        @type event:    wx event
+        """
+
+        # Use ESC to close the window.
+        if event.GetKeyCode() == wx.WXK_ESCAPE:
+            self.handler_close(event)
+
+
     def handler_timer(self, event):
         """Event handler for the timer.
 
@@ -599,6 +629,9 @@ class LogCtrl(wx.stc.StyledTextCtrl):
         # Initialise the base class.
         super(LogCtrl, self).__init__(parent, id=id, pos=pos, size=size, style=style, name=name)
 
+        # Flag for scrolling to the bottom.
+        self.at_end = True
+
         # Turn on line wrapping.
         self.SetWrapMode(wx.stc.STC_WRAP_WORD)
 
@@ -631,16 +664,6 @@ class LogCtrl(wx.stc.StyledTextCtrl):
         # Turn off the pop up menu.
         self.UsePopUp(0)
 
-        # IDs for the menu entries.
-        self.menu_id_find = wx.NewId()
-        self.menu_id_copy = wx.NewId()
-        self.menu_id_select_all = wx.NewId()
-        self.menu_id_zoom_in = wx.NewId()
-        self.menu_id_zoom_out = wx.NewId()
-        self.menu_id_zoom_orig = wx.NewId()
-        self.menu_id_goto_start = wx.NewId()
-        self.menu_id_goto_end = wx.NewId()
-
         # Make the control read only.
         self.SetReadOnly(True)
 
@@ -648,19 +671,19 @@ class LogCtrl(wx.stc.StyledTextCtrl):
         self.orig_zoom = self.GetZoom()
 
         # Bind events.
-        self.Bind(wx.EVT_FIND, self.find)
-        self.Bind(wx.EVT_FIND_NEXT, self.find)
-        self.Bind(wx.EVT_FIND_CLOSE, self.find_close)
         self.Bind(wx.EVT_KEY_DOWN, self.capture_keys)
+        self.Bind(wx.EVT_MOUSE_EVENTS, self.capture_mouse)
+        self.Bind(wx.EVT_MOUSEWHEEL, self.capture_mouse_wheel)
         self.Bind(wx.EVT_RIGHT_DOWN, self.pop_up_menu)
-        self.Bind(wx.EVT_MENU, self.find_open, id=self.menu_id_find)
-        self.Bind(wx.EVT_MENU, self.on_copy, id=self.menu_id_copy)
-        self.Bind(wx.EVT_MENU, self.on_select_all, id=self.menu_id_select_all)
-        self.Bind(wx.EVT_MENU, self.on_zoom_in, id=self.menu_id_zoom_in)
-        self.Bind(wx.EVT_MENU, self.on_zoom_out, id=self.menu_id_zoom_out)
-        self.Bind(wx.EVT_MENU, self.on_zoom_orig, id=self.menu_id_zoom_orig)
-        self.Bind(wx.EVT_MENU, self.on_goto_start, id=self.menu_id_goto_start)
-        self.Bind(wx.EVT_MENU, self.on_goto_end, id=self.menu_id_goto_end)
+        self.Bind(wx.EVT_SCROLLWIN_THUMBTRACK, self.capture_scroll)
+        self.Bind(wx.EVT_MENU, self.find_open, id=MENU_ID_FIND)
+        self.Bind(wx.EVT_MENU, self.on_copy, id=MENU_ID_COPY)
+        self.Bind(wx.EVT_MENU, self.on_select_all, id=MENU_ID_SELECT_ALL)
+        self.Bind(wx.EVT_MENU, self.on_zoom_in, id=MENU_ID_ZOOM_IN)
+        self.Bind(wx.EVT_MENU, self.on_zoom_out, id=MENU_ID_ZOOM_OUT)
+        self.Bind(wx.EVT_MENU, self.on_zoom_orig, id=MENU_ID_ZOOM_ORIG)
+        self.Bind(wx.EVT_MENU, self.on_goto_start, id=MENU_ID_GOTO_START)
+        self.Bind(wx.EVT_MENU, self.on_goto_end, id=MENU_ID_GOTO_END)
 
 
     def capture_keys(self, event):
@@ -680,20 +703,22 @@ class LogCtrl(wx.stc.StyledTextCtrl):
 
         # Select all (Ctrl-A). 
         if event.ControlDown() and event.GetKeyCode() == 65:
-            event.Skip()
+            self.on_select_all(event)
 
         # Find next (Ctrl-G on Mac OS X, F3 on all others).
         if 'darwin' in sys.platform and event.ControlDown() and event.GetKeyCode() == 71:
             self.find_next(event)
-        elif 'darwin' not in sys.platform and event.GetKeyCode() == 342:
+        elif 'darwin' not in sys.platform and event.GetKeyCode() == wx.WXK_F3:
             self.find_next(event)
 
         # Allow caret movements (arrow keys, home, end).
-        if event.GetKeyCode() in [312, 313, 314, 315, 316, 317]:
+        if event.GetKeyCode() in [wx.WXK_END, wx.WXK_HOME, wx.WXK_LEFT, wx.WXK_UP, wx.WXK_RIGHT, wx.WXK_DOWN]:
+            self.at_end = False
             event.Skip()
 
         # Allow scrolling (pg up, pg dn):
-        if event.GetKeyCode() in [366, 367]:
+        if event.GetKeyCode() in [wx.WXK_PAGEUP, wx.WXK_PAGEDOWN]:
+            self.at_end = False
             event.Skip()
 
         # Zooming.
@@ -705,11 +730,67 @@ class LogCtrl(wx.stc.StyledTextCtrl):
             self.on_zoom_in(event)
 
         # Jump to start or end (Ctrl-Home and Ctrl-End).
-        if event.ControlDown() and event.GetKeyCode() == 316:
+        if event.ControlDown() and event.GetKeyCode() == wx.WXK_HOME:
             self.on_goto_start(event)
-        elif event.ControlDown() and event.GetKeyCode() == 317:
+        elif event.ControlDown() and event.GetKeyCode() == wx.WXK_END:
             self.on_goto_end(event)
 
+        # Use ESC to close the window.
+        if event.GetKeyCode() == wx.WXK_ESCAPE:
+            self.controller.handler_close(event)
+
+
+    def capture_mouse(self, event):
+        """Control the mouse events.
+
+        @param event:   The wx event.
+        @type event:    wx event
+        """
+
+        # Stop following the end if a mouse button is clicked.
+        if event.ButtonDown():
+            self.at_end = False
+
+        # Continue with the event.
+        event.Skip()
+
+
+    def capture_mouse_wheel(self, event):
+        """Control the mouse wheel events.
+
+        @param event:   The wx event.
+        @type event:    wx event
+        """
+
+        # Stop following the end on all events.
+        self.at_end = False
+
+        # Move the caret with the scroll, to prevent following the end.
+        scroll = event.GetLinesPerAction()
+        if event.GetWheelRotation() > 0.0:
+            scroll *= -1
+        self.GotoLine(self.GetCurrentLine() + scroll)
+
+        # Continue with the event.
+        event.Skip()
+
+
+    def capture_scroll(self, event):
+        """Control the window scrolling events.
+
+        @param event:   The wx event.
+        @type event:    wx event
+        """
+
+        # Stop following the end on all events.
+        self.at_end = False
+
+        # Move the caret with the scroll (at the bottom), to prevent following the end.
+        self.GotoLine(event.GetPosition() + self.LinesOnScreen() - 1)
+
+        # Continue with the event.
+        event.Skip()
+
 
     def clear(self):
         """Remove all text from the log."""
@@ -735,7 +816,7 @@ class LogCtrl(wx.stc.StyledTextCtrl):
         sel = self.find_data.GetFindString()
 
         # The search flags.
-        flags = event.GetFlags()
+        flags = self.find_data.GetFlags()
 
         # Shift the search anchor 1 character forwards (if not at the end) to ensure the next instance is found.
         pos = self.GetCurrentPos()
@@ -772,9 +853,12 @@ class LogCtrl(wx.stc.StyledTextCtrl):
 
         # Found text.
         else:
-            # Move to the line.
+            # Make the text visible.
             self.EnsureCaretVisible()
 
+            # Stop following the end on all events.
+            self.at_end = False
+
 
     def find_close(self, event):
         """Close the find dialog.
@@ -797,9 +881,20 @@ class LogCtrl(wx.stc.StyledTextCtrl):
         @type event:    wx event
         """
 
+        # Turn off the end flag.
+        self.at_end = False
+
         # Initialise the dialog if it doesn't exist.
         if self.find_dlg == None:
+            # Initalise.
             self.find_dlg = wx.FindReplaceDialog(self, self.find_data, "Find")
+
+            # Bind the find events to this dialog.
+            self.find_dlg.Bind(wx.EVT_FIND, self.find)
+            self.find_dlg.Bind(wx.EVT_FIND_NEXT, self.find)
+            self.find_dlg.Bind(wx.EVT_FIND_CLOSE, self.find_close)
+
+            # Show the dialog.
             if status.show_gui:
                 self.find_dlg.Show(True)
 
@@ -815,6 +910,9 @@ class LogCtrl(wx.stc.StyledTextCtrl):
         @type event:    wx event
         """
 
+        # Turn off the end flag.
+        self.at_end = False
+
         # Text has already been set.
         if self.find_data.GetFindString():
             self.find(event)
@@ -936,6 +1034,9 @@ class LogCtrl(wx.stc.StyledTextCtrl):
         @type event:    wx event
         """
 
+        # Turn on the end flag.
+        self.at_end = True
+
         # Go to the end.
         self.GotoPos(self.GetLength())
 
@@ -947,6 +1048,9 @@ class LogCtrl(wx.stc.StyledTextCtrl):
         @type event:    wx event
         """
 
+        # Turn off the end flag.
+        self.at_end = False
+
         # Go to the start.
         self.GotoPos(-1)
 
@@ -958,6 +1062,12 @@ class LogCtrl(wx.stc.StyledTextCtrl):
         @type event:    wx event
         """
 
+        # Turn off the end flag.
+        self.at_end = False
+
+        # Go to the first line.
+        self.GotoPos(1)
+
         # Select all text in the control.
         self.SelectAll()
 
@@ -1006,27 +1116,33 @@ class LogCtrl(wx.stc.StyledTextCtrl):
         menu = wx.Menu()
 
         # Add the entries.
-        menu.AppendItem(build_menu_item(menu, id=self.menu_id_find, text="&Find", icon=fetch_icon('oxygen.actions.edit-find', "16x16")))
+        menu.AppendItem(build_menu_item(menu, id=MENU_ID_FIND, text="&Find", icon=fetch_icon('oxygen.actions.edit-find', "16x16")))
         menu.AppendSeparator()
-        menu.AppendItem(build_menu_item(menu, id=self.menu_id_copy, text="&Copy", icon=fetch_icon('oxygen.actions.edit-copy', "16x16")))
-        menu.AppendItem(build_menu_item(menu, id=self.menu_id_select_all, text="&Select all", icon=fetch_icon('oxygen.actions.edit-select-all', "16x16")))
+        menu.AppendItem(build_menu_item(menu, id=MENU_ID_COPY, text="&Copy", icon=fetch_icon('oxygen.actions.edit-copy', "16x16")))
+        menu.AppendItem(build_menu_item(menu, id=MENU_ID_SELECT_ALL, text="&Select all", icon=fetch_icon('oxygen.actions.edit-select-all', "16x16")))
         menu.AppendSeparator()
-        menu.AppendItem(build_menu_item(menu, id=self.menu_id_zoom_in, text="Zoom &in", icon=fetch_icon('oxygen.actions.zoom-in', "16x16")))
-        menu.AppendItem(build_menu_item(menu, id=self.menu_id_zoom_out, text="Zoom &out", icon=fetch_icon('oxygen.actions.zoom-out', "16x16")))
-        menu.AppendItem(build_menu_item(menu, id=self.menu_id_zoom_orig, text="Original &zoom", icon=fetch_icon('oxygen.actions.zoom-original', "16x16")))
+        menu.AppendItem(build_menu_item(menu, id=MENU_ID_ZOOM_IN, text="Zoom &in", icon=fetch_icon('oxygen.actions.zoom-in', "16x16")))
+        menu.AppendItem(build_menu_item(menu, id=MENU_ID_ZOOM_OUT, text="Zoom &out", icon=fetch_icon('oxygen.actions.zoom-out', "16x16")))
+        menu.AppendItem(build_menu_item(menu, id=MENU_ID_ZOOM_ORIG, text="Original &zoom", icon=fetch_icon('oxygen.actions.zoom-original', "16x16")))
         menu.AppendSeparator()
-        menu.AppendItem(build_menu_item(menu, id=self.menu_id_goto_start, text="&Go to start", icon=fetch_icon('oxygen.actions.go-top', "16x16")))
-        menu.AppendItem(build_menu_item(menu, id=self.menu_id_goto_end, text="&Go to end", icon=fetch_icon('oxygen.actions.go-bottom', "16x16")))
+        menu.AppendItem(build_menu_item(menu, id=MENU_ID_GOTO_START, text="&Go to start", icon=fetch_icon('oxygen.actions.go-top', "16x16")))
+        menu.AppendItem(build_menu_item(menu, id=MENU_ID_GOTO_END, text="&Go to end", icon=fetch_icon('oxygen.actions.go-bottom', "16x16")))
 
         # Pop up the menu.
         if status.show_gui:
             self.PopupMenu(menu)
-            menu.Destroy()
+
+        # Cleanup.
+        menu.Destroy()
 
 
     def write(self):
         """Write the text in the log queue to the log control."""
 
+        # At the end?
+        if self.GetScrollRange(wx.VERTICAL) - self.GetCurrentLine() <= 1:
+            self.at_end = True
+
         # Get the text.
         string_list, stream_list = self.get_text()
 
@@ -1034,11 +1150,6 @@ class LogCtrl(wx.stc.StyledTextCtrl):
         if len(string_list) == 1 and string_list[0] == '':
             return
 
-        # At the end?
-        at_end = False
-        if self.GetScrollPos(wx.VERTICAL) == self.GetScrollRange(wx.VERTICAL) - self.LinesOnScreen():
-            at_end = True
-
         # Turn of the read only state.
         self.SetReadOnly(False)
 
@@ -1073,8 +1184,8 @@ class LogCtrl(wx.stc.StyledTextCtrl):
         self.limit_scrollback()
 
         # Stay at the end.
-        if at_end:
-            self.ScrollToLine(self.GetLineCount())
+        if self.at_end:
+            self.DocumentEnd()
 
         # Make the control read only again.
         self.SetReadOnly(True)
