@@ -23,14 +23,15 @@
 """The N-state model or structural ensemble analysis parameter handling."""
 
 # Python module imports.
-from numpy import array, float64, identity, zeros
+from numpy import array, float64, zeros
 from re import search
 from warnings import warn
 
 # relax module imports.
 from lib.errors import RelaxNoModelError
 from lib.warnings import RelaxWarning
-from pipe_control import align_tensor, pipes
+from pipe_control import align_tensor
+from pipe_control.pipes import check_pipe
 from pipe_control.align_tensor import opt_uses_align_data, opt_uses_tensor
 from specific_analyses.n_state_model.data import base_data_types
 
@@ -61,8 +62,13 @@ def assemble_param_vector(sim_index=None):
             if not opt_uses_tensor(cdp.align_tensors[i]):
                 continue
 
-            # Add the parameters.
-            param_vector = param_vector + list(cdp.align_tensors[i].A_5D)
+            # No values set.
+            if not hasattr(cdp.align_tensors[i], 'A_5D'):
+                param_vector += [None, None, None, None, None]
+
+            # Otherwise add the parameters.
+            else:
+                param_vector += list(cdp.align_tensors[i].A_5D)
 
     # Monte Carlo simulation data structures.
     if sim_index != None:
@@ -103,11 +109,11 @@ def assemble_param_vector(sim_index=None):
     if hasattr(cdp, 'paramag_centre_fixed') and not cdp.paramag_centre_fixed:
         if not hasattr(cdp, 'paramagnetic_centre'):
             for i in range(3):
-                param_vector.append(0.0)
+                param_vector.append(None)
         elif sim_index != None:
             if cdp.paramagnetic_centre_sim[sim_index] == None:
                 for i in range(3):
-                    param_vector.append(0.0)
+                    param_vector.append(None)
             else:
                 for i in range(3):
                     param_vector.append(cdp.paramagnetic_centre_sim[sim_index][i])
@@ -115,69 +121,10 @@ def assemble_param_vector(sim_index=None):
             for i in range(3):
                 param_vector.append(cdp.paramagnetic_centre[i])
 
-    # Convert all None values to zero (to avoid conversion to NaN).
-    for i in range(len(param_vector)):
-        if param_vector[i] == None:
-            param_vector[i] = 0.0
-
     # Return a numpy arrary.
     return array(param_vector, float64)
 
 
-def assemble_scaling_matrix(data_types=None, scaling=True):
-    """Create and return the scaling matrix.
-
-    @keyword data_types:    The base data types used in the optimisation.  This list can contain
-                            the elements 'rdc', 'pcs' or 'tensor'.
-    @type data_types:       list of str
-    @keyword scaling:       If False, then the identity matrix will be returned.
-    @type scaling:          bool
-    @return:                The square and diagonal scaling matrix.
-    @rtype:                 numpy rank-2 array
-    """
-
-    # Initialise.
-    scaling_matrix = identity(param_num(), float64)
-
-    # Return the identity matrix.
-    if not scaling:
-        return scaling_matrix
-
-    # Starting point of the populations.
-    pop_start = 0
-
-    # Loop over the alignments.
-    tensor_num = 0
-    for i in range(len(cdp.align_tensors)):
-        # Skip non-optimised tensors.
-        if not opt_uses_tensor(cdp.align_tensors[i]):
-            continue
-
-        # Add the 5 alignment parameters.
-        pop_start = pop_start + 5
-
-        # The alignment parameters.
-        for j in range(5):
-            scaling_matrix[5*tensor_num + j, 5*tensor_num + j] = 1.0
-
-        # Increase the tensor number.
-        tensor_num += 1
-
-    # Loop over the populations, and set the scaling factor.
-    if cdp.model in ['2-domain', 'population']:
-        factor = 0.1
-        for i in range(pop_start, pop_start + (cdp.N-1)):
-            scaling_matrix[i, i] = factor
-
-    # The paramagnetic centre.
-    if hasattr(cdp, 'paramag_centre_fixed') and not cdp.paramag_centre_fixed:
-        for i in range(-3, 0):
-            scaling_matrix[i, i] = 1e2
-
-    # Return the matrix.
-    return scaling_matrix
-
-
 def disassemble_param_vector(param_vector=None, data_types=None, sim_index=None):
     """Disassemble the parameter vector and place the values into the relevant variables.
 
@@ -290,7 +237,7 @@ def elim_no_prob():
     """Remove all structures or states which have no probability."""
 
     # Test if the current data pipe exists.
-    pipes.test()
+    check_pipe()
 
     # Test if the model is setup.
     if not hasattr(cdp, 'model'):
@@ -438,7 +385,7 @@ def number_of_states(N=None):
     """
 
     # Test if the current data pipe exists.
-    pipes.test()
+    check_pipe()
 
     # Set the value of N.
     cdp.N = N
@@ -525,7 +472,7 @@ def ref_domain(ref=None):
     """
 
     # Test if the current data pipe exists.
-    pipes.test()
+    check_pipe()
 
     # Test if the model is setup.
     if not hasattr(cdp, 'model'):
@@ -558,7 +505,7 @@ def select_model(model=None):
     """
 
     # Test if the current data pipe exists.
-    pipes.test()
+    check_pipe()
 
     # Test if the model name exists.
     if not model in ['2-domain', 'population', 'fixed']:
@@ -629,7 +576,7 @@ def update_model():
         for id in cdp.align_ids:
             # No tensors initialised.
             if not hasattr(cdp, 'align_tensors'):
-                align_tensor.init(tensor=id, align_id=id, params=[0.0, 0.0, 0.0, 0.0, 0.0])
+                align_tensor.init(tensor=id, align_id=id)
 
             # Find if the tensor corresponding to the id exists.
             exists = False
@@ -639,4 +586,4 @@ def update_model():
 
             # Initialise the tensor.
             if not exists:
-                align_tensor.init(tensor=id, align_id=id, params=[0.0, 0.0, 0.0, 0.0, 0.0])
+                align_tensor.init(tensor=id, align_id=id)
