@@ -59,6 +59,7 @@ class Status(object):
             self._instance.show_gui = False
             self._instance.gui_uf_force_sync = False
             self._instance.install_path = self._instance._det_install_path()
+            self._instance.skip_blacklisted_tests = True
 
             # Set up the singleton.
             self._instance._setup()
@@ -594,7 +595,7 @@ class Observer_container:
         """Print out info about all the status objects."""
 
         # Blacklisted objects.
-        blacklist = list(self.__class__.__dict__.keys() + dict.__dict__.keys())
+        blacklist = list(self.__class__.__dict__.keys()) + list(dict.__dict__.keys())
 
         # Loop over all objects in this container.
         for name in dir(self):
