@@ -72,6 +72,8 @@ class PackageTestCase(UnitTestCase):
                 module = module[:-3]
             if search('.so$', module):
                 module = module[:-3]
+            if search('.pyd$', module):
+                module = module[:-4]
 
             # Printout.
             print("    Module/package:  %s" % module)
@@ -89,6 +91,12 @@ class PackageTestCase(UnitTestCase):
             if access(self.package_path+sep+module+'.py', F_OK):
                 continue
 
+            # Check for the C module.
+            if access(self.package_path+sep+module+'.so', F_OK):
+                continue
+            if access(self.package_path+sep+module+'.pyd', F_OK):
+                continue
+
             # Check for the package.
             if access(self.package_path+sep+module, F_OK):
                 continue
