@@ -38,6 +38,7 @@ from pipe_control import pymol_control
 from specific_analyses.model_free.uf import classic_style_doc
 from user_functions.data import Uf_info; uf_info = Uf_info()
 from user_functions.objects import Desc_container
+from user_functions.wildcards import WILDCARD_PYMOL_MACRO, WILDCARD_STRUCT_PDB_ALL
 
 
 # The user function class.
@@ -118,7 +119,7 @@ uf.add_keyarg(
     arg_type = "file sel",
     desc_short = "file name",
     desc = "The name of the PDB file containing the cone geometric object.",
-    wiz_filesel_wildcard = "PDB files (*.pdb)|*.pdb;*.PDB",
+    wiz_filesel_wildcard = WILDCARD_STRUCT_PDB_ALL,
     wiz_filesel_style = FD_OPEN
 )
 # Description.
@@ -154,8 +155,9 @@ uf.add_keyarg(
     arg_type = "file sel",
     desc_short = "average structure file name",
     desc = "The name of the 3D structure PDB file for the molecular structure with the moving domains shifted to the average position.",
-    wiz_filesel_wildcard = "PDB files (*.pdb)|*.pdb;*.PDB",
-    wiz_filesel_style = FD_OPEN
+    wiz_filesel_wildcard = WILDCARD_STRUCT_PDB_ALL,
+    wiz_filesel_style = FD_OPEN,
+    can_be_none = True
 )
 uf.add_keyarg(
     name = "rep_file",
@@ -164,8 +166,9 @@ uf.add_keyarg(
     arg_type = "file sel",
     desc_short = "PDB representation file name",
     desc = "The name of the PDB file for the geometric object representation of the frame order dynamics.",
-    wiz_filesel_wildcard = "PDB files (*.pdb)|*.pdb;*.PDB",
-    wiz_filesel_style = FD_OPEN
+    wiz_filesel_wildcard = WILDCARD_STRUCT_PDB_ALL,
+    wiz_filesel_style = FD_OPEN,
+    can_be_none = True
 )
 uf.add_keyarg(
     name = "dist_file",
@@ -174,8 +177,9 @@ uf.add_keyarg(
     arg_type = "file sel",
     desc_short = "distribution file name",
     desc = "The name of the file which will contain multiple models spanning the full dynamics distribution of the frame order model.",
-    wiz_filesel_wildcard = "PDB files (*.pdb)|*.pdb;*.PDB",
-    wiz_filesel_style = FD_OPEN
+    wiz_filesel_wildcard = WILDCARD_STRUCT_PDB_ALL,
+    wiz_filesel_style = FD_OPEN,
+    can_be_none = True
 )
 uf.add_keyarg(
     name = "dir",
@@ -289,7 +293,7 @@ uf.add_keyarg(
     arg_type = "file sel",
     desc_short = "file name",
     desc = "The name of the PyMOL macro file.",
-    wiz_filesel_wildcard = "PyMOL macro files (*.pml)|*.pml;*.PML",
+    wiz_filesel_wildcard = WILDCARD_PYMOL_MACRO,
     wiz_filesel_style = FD_OPEN
 )
 uf.add_keyarg(
@@ -382,7 +386,7 @@ uf.add_keyarg(
     arg_type = "file sel",
     desc_short = "file name",
     desc = "The optional name of the file.",
-    wiz_filesel_wildcard = "PyMOL macro files (*.pml)|*.pml;*.PML",
+    wiz_filesel_wildcard = WILDCARD_PYMOL_MACRO,
     wiz_filesel_style = FD_SAVE,
     can_be_none = True
 )
@@ -433,7 +437,7 @@ uf.add_keyarg(
     arg_type = "file sel",
     desc_short = "file name",
     desc = "The name of the PDB file containing the tensor geometric object.",
-    wiz_filesel_wildcard = "PDB files (*.pdb)|*.pdb;*.PDB",
+    wiz_filesel_wildcard = WILDCARD_STRUCT_PDB_ALL,
     wiz_filesel_style = FD_OPEN
 )
 # Description.
@@ -473,7 +477,7 @@ uf.add_keyarg(
     arg_type = "file sel",
     desc_short = "file name",
     desc = "The name of the PDB file containing the vector distribution.",
-    wiz_filesel_wildcard = "PDB files (*.pdb)|*.pdb;*.PDB",
+    wiz_filesel_wildcard = WILDCARD_STRUCT_PDB_ALL,
     wiz_filesel_style = FD_OPEN
 )
 # Description.
